@@ -1,4 +1,8 @@
-from django.forms import Textarea
+try:
+    from django.forms import Textarea
+except ImportError:
+    """incase we're installing and django isn't installed"""
+    Textarea = object
 
 class FullScreenTextarea(Textarea):
 
@@ -12,7 +16,7 @@ class FullScreenTextarea(Textarea):
     class Media:
         css = {
             'screen': (
-                'http://fonts.googleapis.com/css?family=Lato',
+                'https://fonts.googleapis.com/css?family=Lato',
                 'writingfield/writingfield.css',)
         }
         js = (
